@@ -3,28 +3,39 @@ module YARD
     module Commands
       # Displays documentation for a specific object identified by the path
       class DisplayObjectCommand < LibraryCommand
+        include DocServerHelper
+
         def run
-          return index if path.empty?
+          if path.empty?
+            if options.readme
+              filename = options.readme.filename
+              opts = adapter.options.merge(
+                :index => true, :library => library,
+                :path => filename.sub(%r{^#{library.source_path.to_s}/}, ''))
+              self.status, self.headers, self.body =
+                *DisplayFileCommand.new(opts).call(request)
+              cache(self.body)
+              return
+            else
+              self.path = 'index'
+            end
+          end
+          return index if path == 'index'
 
           if object = Registry.at(object_path)
             options.update(:type => :layout)
             render(object)
           else
-            self.status = 404
+            not_found
           end
         end
 
         def index
           Registry.load_all
 
-          title = options[:title]
-          unless title
-            title = "Documentation for #{library.name} #{library.version ? '(' + library.version + ')' : ''}"
-          end
           options.update(
             :object => '_index.html',
             :objects => Registry.all(:module, :class),
-            :title => title,
             :type => :layout
           )
           render
